import asyncio
import datetime
import logging
import sys
from typing import List

from config import Config
from use_cases import account_setup, external_auth, market_limits, flow_tracking


_use_case_map = {
    'account_setup': account_setup,
    'external_auth': external_auth,
    'market_limits': market_limits,
    'flow_tracking': flow_tracking
}


def main(argv: List[str]):
    if len(argv) < 1:
        print(f"Name of use case script (without extension) is expected as first command line argument. Example: account_setup")
        return

    use_case = argv[0]

    if use_case not in _use_case_map.keys():
        print(f"Incorrect use case: {use_case}")
        return

    logging.basicConfig(filename=f'./logs/{use_case}--{datetime.datetime.now().strftime("%Y-%m-%d_%H_%M_%S")}.log',
        filemode='w', encoding='utf-8', level=logging.DEBUG)

    config = Config()

    loop = asyncio.get_event_loop()
    loop.run_until_complete(_use_case_map[use_case].run(config))


if __name__ == "__main__":
    main(sys.argv[1:])
